import { Patch } from 'immer';
export type { Patch };
/**
 * Take an array of Immer patches and compress them down to the smallest amount of patches
 * @link https://medium.com/@dedels/using-immer-to-compress-immer-patches-f382835b6c69
 */
export declare function compressPatches<Data>({ baseData, patches: allPatches, }: {
    baseData: Data;
    patches: Patch[][] | Patch[];
}): readonly [Data, Patch[], Patch[]];
/**
 * Loop over changes to applyPatches in small batches (safer) instead of all at once
 * If there are errors, it will skip that change and continue on
 */
export declare function applyPatchesSafely<Data>({ data, changes, logError, }: {
    data: Data;
    changes: {
        patches: Patch[];
    }[];
    logError?: (msg: unknown, ...optionalMsgs: unknown[]) => void;
}): Data;
//# sourceMappingURL=immer.d.ts.map