import camelCase from 'lodash/camelCase.js';
import kebabCase from 'just-kebab-case';
export { default as snakeCase } from 'lodash/snakeCase.js';
export { default as capitalize } from 'lodash/capitalize.js';
export { camelCase, kebabCase, kebabCase as paramCase };
/**
 * This function takes a string and escapes any regex related characters
 * Intended to be used to "cleanse" user input of regex that causes failures when using string operators
 */
export declare function escapeRegEx(string: string): string;
/**
 * Basic "fuzzy" search of one string within another.
 * Both the haystack and needle are escaped for regex characters, then converted to lower case
 * If the needle appears in the haystack, will return true, otherwise returns false
 * @param {string} haystack - string to seach within
 * @param {string} needle - string being searched for
 * @returns {boolean}
 */
export declare function containsString(haystack: string, needle: string): boolean;
export declare function capitalizeFirstLetter(string: string): string;
export declare function isFirstLetterCapital(str: string): boolean;
/**
 * Transform into a string of capitalized words without separators. How React Component names are transformed.
 * aka PascalCase
 */
export declare function upperCamelCase(str: string): string;
export declare const pascalCase: typeof upperCamelCase;
export declare function base64ToString(b64: string): string;
export declare function stringToBase64(string: string): string;
/**
 * check if a value is a valid Base64 string
 */
export declare function isBase64(src: unknown): src is string;
export declare function stringHasSpaces(string: string): boolean;
/**
 * Removes the NPM "@scope" in pkg names
 * `@scope/name` => `name`
 * `name` => `name`
 */
export declare function removeNpmScope(pkgName: string): string;
export declare function isUrl(url: unknown): url is string;
/**
 * Check that email is < 320 chars (according to spec), then if passes regex.
 * @link https://www.rfc-editor.org/errata/eid1690#:~:text=It%20should%20say%3A-,In%20addition%20to%20restrictions%20on%20syntax%2C%20there%20is%20a%20length,total%20length%20of%20320%20characters.
 */
export declare const isEmail: (email: unknown) => email is string;
/**
 * Returns "knapsack.cloud" from "bloom@knapsack.cloud", if valid email
 */
export declare const getDomainFromEmail: (email: string) => string | null;
/**
 * Basic auth headers are username:password in base64, decode and compare
 */
export declare const decodeBasicAuth: (auth: string) => {
    username: string;
    password: string;
};
/**
 * Parse a string that may contain a unit, like "10px" or "10%"
 */
export declare function parseNumberWithUnit(value: string | number): {
    value: number;
    unit?: string;
};
/**
 * Check if a strings first character is a letter
 */
export declare function startsWithLetter(str: string): boolean;
export declare function removeWrappingDoubleQuotes(str: string): string;
//# sourceMappingURL=strings.d.ts.map